==> open-xchange-subscribe_6.18.0.0.orig.tar.gz: open-xchange-subscribe-6.18.0.0/test/com/openexchange/subscribe/database/SubscriptionUserDeleteListenerTest.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.subscribe.database;

import static com.openexchange.java.Autoboxing.I;
import static com.openexchange.sql.grammar.Constant.ASTERISK;
import static com.openexchange.sql.schema.Tables.subscriptions;
import java.sql.Connection;
import java.sql.SQLException;
import com.openexchange.groupware.delete.DeleteEvent;
import com.openexchange.groupware.delete.DeleteFailedException;
import com.openexchange.groupware.ldap.MockUser;
import com.openexchange.groupware.tx.TransactionException;
import com.openexchange.sql.builder.StatementBuilder;
import com.openexchange.sql.grammar.EQUALS;
import com.openexchange.sql.grammar.SELECT;
import com.openexchange.subscribe.SubscriptionException;
import com.openexchange.subscribe.SubscriptionStorage;
import com.openexchange.subscribe.sql.AbstractSubscriptionSQLStorageTest;

/**
 * {@link SubscriptionUserDeleteListenerTest}
 * 
 * @author <a href="mailto:tobias.prinz@open-xchange.com">Tobias Prinz</a>
 */
public class SubscriptionUserDeleteListenerTest extends AbstractSubscriptionSQLStorageTest {

    public void testShouldDeleteSubscriptionOnDeletionOfUser() throws SubscriptionException, TransactionException, DeleteFailedException, SQLException {
        Connection writeConnection = getDBProvider().getWriteConnection(ctx);

        SubscriptionUserDeleteListener listener = new SubscriptionUserDeleteListener() {
            @Override
            protected SubscriptionStorage getStorage(Connection writeCon) {
                return storage;
            }
        };

        MockUser user = new MockUser(userId);

        storage.rememberSubscription(subscription);
        DeleteEvent event = new DeleteEvent(user, userId, DeleteEvent.TYPE_USER, ctx);
        listener.deletePerformed(event, null, writeConnection);

        SELECT select = new SELECT(ASTERISK).FROM(subscriptions).WHERE(
            new EQUALS("cid", I(ctx.getContextId())).AND(new EQUALS("user_id", I(userId))));
        assertNoResult(new StatementBuilder().buildCommand(select));
    }
}

==> open-xchange-subscribe_6.20.8.0.orig.tar.gz: open-xchange-subscribe-6.20.8.0/test/com/openexchange/subscribe/database/SubscriptionUserDeleteListenerTest.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.subscribe.database;

import static com.openexchange.java.Autoboxing.I;
import static com.openexchange.sql.grammar.Constant.ASTERISK;
import static com.openexchange.sql.schema.Tables.subscriptions;
import java.sql.Connection;
import java.sql.SQLException;
import com.openexchange.database.DBPoolingException;
import com.openexchange.groupware.delete.DeleteEvent;
import com.openexchange.groupware.delete.DeleteFailedException;
import com.openexchange.groupware.ldap.MockUser;
import com.openexchange.sql.builder.StatementBuilder;
import com.openexchange.sql.grammar.EQUALS;
import com.openexchange.sql.grammar.SELECT;
import com.openexchange.subscribe.SubscriptionException;
import com.openexchange.subscribe.SubscriptionStorage;
import com.openexchange.subscribe.sql.AbstractSubscriptionSQLStorageTest;

/**
 * {@link SubscriptionUserDeleteListenerTest}
 * 
 * @author <a href="mailto:tobias.prinz@open-xchange.com">Tobias Prinz</a>
 */
public class SubscriptionUserDeleteListenerTest extends AbstractSubscriptionSQLStorageTest {

    public void testShouldDeleteSubscriptionOnDeletionOfUser() throws SubscriptionException, DBPoolingException, DeleteFailedException, SQLException {
        Connection writeConnection = getDBProvider().getWriteConnection(ctx);

        SubscriptionUserDeleteListener listener = new SubscriptionUserDeleteListener() {
            @Override
            protected SubscriptionStorage getStorage(Connection writeCon) {
                return storage;
            }
        };

        MockUser user = new MockUser(userId);

        storage.rememberSubscription(subscription);
        DeleteEvent event = new DeleteEvent(user, userId, DeleteEvent.TYPE_USER, ctx);
        listener.deletePerformed(event, null, writeConnection);

        SELECT select = new SELECT(ASTERISK).FROM(subscriptions).WHERE(
            new EQUALS("cid", I(ctx.getContextId())).AND(new EQUALS("user_id", I(userId))));
        assertNoResult(new StatementBuilder().buildCommand(select));
    }
}
